<?php

namespace EventPortal\AuthPassword\Http\Controllers;

use EventPortal\AuthPassword\Rules;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Routing\Controller;
use Inertia\Inertia;
use Throwable;

class ResetPasswordController extends Controller
{
    use ResetsPasswords;

    /**
     * @return mixed
     */
    public function showResetForm()
    {
        try {
            /** @phpstan-ignore-next-line */
            $user = $this->broker()->getUser(['email' => request()->get('email')]);
        } catch (Throwable $e) {
            return redirect()->route('login.index');
        }

        if ($user === null) {
            return redirect()->route('login.index');
        }

        /** @phpstan-ignore-next-line */
        if (!$this->broker()->tokenExists($user, request()->get('token'))) {
            return redirect()->route('login.index');
        }

        return Inertia::render('ResetPassword/Index', [
            'email' => request()->email,
            'token' => request()->token,
            'rules' => Rules::forPassword(),
        ]);
    }

    public function redirectPath(): string
    {
        return route('login.index');
    }

    protected function rules(): array
    {
        return Rules::forPassword();
    }
}
